.. Bowtie documentation master file, created by
   sphinx-quickstart on Fri Aug 19 23:07:25 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Bowtie: Interactive Dashboard Toolkit
=====================================

Bowtie helps you visualize your data interactively.
No Javascript required, you build your dashboard in pure Python.
Easy to deploy so you can share results with others.

.. toctree::
    :maxdepth: 2

    quickstart
    layout
    components
    cache
    docker
    architecture
    newcomponents
    comparison
    indices
